Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(81)

Unified Diff: net/quic/quartc/quartc_stream_test.cc

Issue 2487613002: Landing Recent QUIC changes until 12:43 PM, Nov 5, 2016 UTC+8 (Closed)
Patch Set: Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/quic/quartc/quartc_stream.cc ('k') | net/quic/test_tools/quic_session_peer.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/quic/quartc/quartc_stream_test.cc
diff --git a/net/quic/quartc/quartc_stream_test.cc b/net/quic/quartc/quartc_stream_test.cc
index f862a70254301cb6324f70d2f0371804ea818d5f..d138705afd4305d8b01c398dd9f8ea95e0cddcbf 100644
--- a/net/quic/quartc/quartc_stream_test.cc
+++ b/net/quic/quartc/quartc_stream_test.cc
@@ -21,7 +21,7 @@ static const QuicStreamId kStreamId = 5;
static const QuartcStreamInterface::WriteParameters kDefaultParam;
// MockQuicSession that does not create streams and writes data from
// ReliableQuicStream to a string.
class MockQuicSession : public QuicSession {
public:
MockQuicSession(QuicConnection* connection,
@@ -30,9 +30,9 @@ class MockQuicSession : public QuicSession {
: QuicSession(connection, nullptr /*visitor*/, config),
write_buffer_(write_buffer) {}
// Writes outgoing data from ReliableQuicStream to a string.
QuicConsumedData WritevData(
- ReliableQuicStream* stream,
+ QuicStream* stream,
QuicStreamId id,
QuicIOVector iovector,
QuicStreamOffset offset,
@@ -58,7 +58,7 @@ class MockQuicSession : public QuicSession {
QuicCryptoStream* GetCryptoStream() override { return nullptr; }
// Called by ReliableQuicStream when they want to close stream.
void SendRstStream(QuicStreamId id,
QuicRstStreamErrorCode error,
QuicStreamOffset bytes_written) override {}
@@ -72,7 +72,7 @@ class MockQuicSession : public QuicSession {
}
// The session take ownership of the stream.
- void ActivateReliableStream(std::unique_ptr<ReliableQuicStream> stream) {
+ void ActivateReliableStream(std::unique_ptr<QuicStream> stream) {
ActivateStream(std::move(stream));
}
@@ -136,9 +136,9 @@ class MockQuartcStreamDelegate : public QuartcStreamInterface::Delegate {
protected:
uint32_t id_;
// Data read by the ReliableQuicStream.
std::string& read_buffer_;
// Whether the ReliableQuicStream is closed.
bool closed_ = false;
int queued_bytes_amount_ = -1;
};
@@ -21,7 +21,7 @@ static const QuicStreamId kStreamId = 5;
static const QuartcStreamInterface::WriteParameters kDefaultParam;
// MockQuicSession that does not create streams and writes data from
-// ReliableQuicStream to a string.
+// QuicStream to a string.
class MockQuicSession : public QuicSession {
public:
@@ -30,9 +30,9 @@ class MockQuicSession : public QuicSession {
: QuicSession(connection, nullptr /*visitor*/, config),
write_buffer_(write_buffer) {}
- // Writes outgoing data from ReliableQuicStream to a string.
+ // Writes outgoing data from QuicStream to a string.
QuicConsumedData WritevData(
@@ -58,7 +58,7 @@ class MockQuicSession : public QuicSession {
QuicCryptoStream* GetCryptoStream() override { return nullptr; }
- // Called by ReliableQuicStream when they want to close stream.
+ // Called by QuicStream when they want to close stream.
void SendRstStream(QuicStreamId id,
QuicRstStreamErrorCode error,
@@ -136,9 +136,9 @@ class MockQuartcStreamDelegate : public QuartcStreamInterface::Delegate {
protected:
uint32_t id_;
- // Data read by the ReliableQuicStream.
+ // Data read by the QuicStream.
std::string& read_buffer_;
@@ -136,9 +136,9 @@ class MockQuartcStreamDelegate : public QuartcStreamInterface::Delegate {
std::string& read_buffer_;
- // Whether the ReliableQuicStream is closed.
+ // Whether the QuicStream is closed.
bool closed_ = false;
int queued_bytes_amount_ = -1;
« no previous file with comments | « net/quic/quartc/quartc_stream.cc ('k') | net/quic/test_tools/quic_session_peer.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698